@@ -33,6 +33,7 @@
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 import struct
+import sys
 
 from eventlet import patcher
 from eventlet.green import _socket_nodns
@@ -42,30 +43,34 @@ from eventlet.green import select
 from eventlet.support import six
 
 
-dns = patcher.import_patched('dns',
-                             select=select,
-                             time=time,
-                             os=os,
-                             socket=_socket_nodns)
-dns.resolver = patcher.import_patched('dns.resolver',
-                                      select=select,
-                                      time=time,
-                                      os=os,
-                                      socket=_socket_nodns)
+def import_patched(module_name):
+    # Import cycle note: it's crucial to use _socket_nodns here because
+    # regular evenlet.green.socket imports *this* module and if we imported
+    # it back we'd end with an import cycle (socket -> greendns -> socket).
+    # We break this import cycle by providing a restricted socket module.
+    # if (module_name + '.').startswith('dns.'):
+    #     module_name = 'eventlet.support.' + module_name
+    modules = {
+        'select': select,
+        'time': time,
+        'os': os,
+        'socket': _socket_nodns,
+    }
+    return patcher.import_patched(module_name, **modules)
 
-for pkg in ('dns.entropy', 'dns.inet', 'dns.query'):
-    setattr(dns, pkg.split('.')[1], patcher.import_patched(pkg,
-                                                           select=select,
-                                                           time=time,
-                                                           os=os,
-                                                           socket=_socket_nodns))
-import dns.rdtypes
-for pkg in ['dns.rdtypes.IN', 'dns.rdtypes.ANY']:
-    setattr(dns.rdtypes, pkg.split('.')[-1], patcher.import_patched(pkg))
-for pkg in ['dns.rdtypes.IN.A', 'dns.rdtypes.IN.AAAA']:
-    setattr(dns.rdtypes.IN, pkg.split('.')[-1], patcher.import_patched(pkg))
-for pkg in ['dns.rdtypes.ANY.CNAME']:
-    setattr(dns.rdtypes.ANY, pkg.split('.')[-1], patcher.import_patched(pkg))
+
+sys.path.insert(0, os.path.abspath(os.path.dirname(__file__)))
+dns = import_patched('dns')
+for pkg in dns.__all__:
+    setattr(dns, pkg, import_patched('dns.' + pkg))
+for pkg in dns.rdtypes.__all__:
+    setattr(dns.rdtypes, pkg, import_patched('dns.rdtypes.' + pkg))
+for pkg in dns.rdtypes.IN.__all__:
+    setattr(dns.rdtypes.IN, pkg, import_patched('dns.rdtypes.IN.' + pkg))
+for pkg in dns.rdtypes.ANY.__all__:
+    setattr(dns.rdtypes.ANY, pkg, import_patched('dns.rdtypes.ANY.' + pkg))
+del import_patched
+sys.path.pop(0)
 
 
 socket = _socket_nodns
@@ -94,6 +99,7 @@ def is_ipv6_addr(host):
     """Return True if host is a valid IPv6 address"""
     if not isinstance(host, six.string_types):
         return False
+    host = host.split('%', 1)[0]
     try:
         dns.ipv6.inet_aton(host)
     except dns.exception.SyntaxError:
@@ -290,12 +296,11 @@ class ResolverProxy(object):
         """
         self._hosts = hosts_resolver
         self._filename = filename
-        self._resolver = dns.resolver.Resolver(filename=self._filename)
-        self._resolver.cache = dns.resolver.LRUCache()
+        self.clear()
 
     def clear(self):
         self._resolver = dns.resolver.Resolver(filename=self._filename)
-        self._resolver.cache = dns.resolver.Cache()
+        self._resolver.cache = dns.resolver.LRUCache()
 
     def query(self, qname, rdtype=dns.rdatatype.A, rdclass=dns.rdataclass.IN,
               tcp=False, source=None, raise_on_no_answer=True):
@@ -397,10 +402,19 @@ def _getaddrinfo_lookup(host, family, flags):
         raise EAI_NONAME_ERROR
     addrs = []
     if family == socket.AF_UNSPEC:
+        err = None
         for qfamily in [socket.AF_INET6, socket.AF_INET]:
-            answer = resolve(host, qfamily, False)
-            if answer.rrset:
-                addrs.extend([rr.address for rr in answer.rrset])
+            try:
+                answer = resolve(host, qfamily, False)
+            except socket.gaierror as e:
+                if e.errno not in (socket.EAI_AGAIN, socket.EAI_NODATA):
+                    raise
+                err = e
+            else:
+                if answer.rrset:
+                    addrs.extend(rr.address for rr in answer.rrset)
+        if err is not None and not addrs:
+            raise err
     elif family == socket.AF_INET6 and flags & socket.AI_V4MAPPED:
         answer = resolve(host, socket.AF_INET6, False)
         if answer.rrset:
